@@ -97,7 +97,7 @@ sub _generate_digest {
     return '' unless ($user->auth_token);
 
 
-
+    Jifty->log->debug($user->id."Creating a digest of", join (', ', $user->auth_token, $self->path, $self->until));
     # build an md5sum of the email token and until and our secret
     my $digest = Digest::MD5->new();
     $digest->add( $user->auth_token );
@@ -221,6 +221,7 @@ sub as_encoded_token {
 sub _generate_token {
     my $self = shift;
     my %args = (email => undef, @_);
+    warn "Generating a token for ".YAML::Dump(\%args);
     return  join ('/', 
         $args{'email'},
         $self->path,
@@ -273,18 +274,22 @@ sub validate {
     # email must exist
 
     unless ($self->_user_from_email($self->email)) {
+        Jifty->log->debug("Token validation failed - Invalid user");
         return undef;
     }
 
     unless ($self->path) {
+        Jifty->log->debug("Token validation failed - Invalid path");
         return undef;
     }
     unless ($self->checksum_provided) {
+        Jifty->log->debug("Token validation failed - Checksum not provided");
         return undef;
     }
 
 
     unless ($self->_correct_checksum_provided) {
+        Jifty->log->debug("Token validation failed - Checksum not correct");
         return undef;
     }
 
@@ -301,11 +306,13 @@ actually do much input checking. You want to call "validate"
 
 sub _correct_checksum_provided {
     my $self = shift;
+        Jifty->log->debug("LetMe checksum: ".$self->checksum_provided . " vs ". $self->generate_checksum );
     return undef
         unless ( $self->checksum_provided eq $self->generate_checksum )
         or
         ( $self->checksum_provided eq $self->generate_koremutake_checksum );
 
+    return 1;
 }
 
 1;
