@@ -3,10 +3,6 @@ use strict;
 
 package Jifty::Server;
 
-=head1 NAME
-
-Jifty::Server - Standalone web server for Jifty applications
-
 =head1 SYNOPSIS
 
   use Jifty::Server;
@@ -20,7 +16,7 @@ creates a handy standalone web server for a lightweight Jifty application.
 
 =cut
 
-use Jifty::Everything;
+
 use base qw/HTTP::Server::Simple::CGI/;
 use base qw/Jifty::Object/;
 use File::Spec;
@@ -36,6 +32,11 @@ Creates a new C<Jifty::Server> object.
 
 =cut
 
+sub _send_http_status {
+      print STDOUT "HTTP/1.0 ".  (Jifty->handler->apache->{headers_out}->{'Status'} || '200 Jifty OK') .  "\n";
+};
+
+
 sub new {
     my $class = shift;
     my $self  = {};
@@ -44,11 +45,8 @@ sub new {
     $self->recording_on if $ENV{'JIFTY_RECORD'};
 
     use Hook::LexWrap;
-    wrap 'HTML::Mason::FakeApache::send_http_header', pre => sub {
-        my $r = shift;
-        my $status = $r->header_out('Status') || '200 Jifty OK';
-        print STDOUT "HTTP/1.0 $status\n";
-    };
+    wrap 'HTML::Mason::FakeApache::send_http_header', pre => \&_send_http_status;
+    
 
     return ($self);
 
