@@ -15,8 +15,9 @@ can be updated via AJAX or via query parameters.
 =cut
 
 use base qw/Jifty::Object Class::Accessor::Fast/;
-__PACKAGE__->mk_accessors(qw(name default_path default_arguments qualified_name parent region_wrapper));
+__PACKAGE__->mk_accessors(qw(name force_path force_arguments default_path default_arguments qualified_name parent region_wrapper));
 use Jifty::JSON;
+use Encode ();
 
 =head2 new PARAMHASH
 
@@ -40,6 +41,15 @@ C</__jifty/empty>, which, as its name implies, is empty.
 Specifies an optional set of parameter defaults.  These should all be
 simple scalars, as they might be passed across HTTP if AJAX is used.
 
+=item force_arguments (optional)
+
+Specifies an optional set of parameter values. They will override anything
+sent by the user or set via AJAX.
+
+=item force_path (optional)
+
+A fixed path to the fragment that this page region contains.  Overrides anything set by the user.
+
 =item parent (optional)
 
 The parent L<Jifty::Web::PageRegion> that this region is enclosed in.
@@ -50,6 +60,9 @@ A boolean; whether or not the region, when rendered, will include the
 HTML region preamble that makes Javascript aware of its presence.
 Defaults to true.
 
+
+=item
+
 =back
 
 =cut
@@ -63,6 +76,8 @@ sub new {
                 path => "/__jifty/empty",
                 defaults => {},
                 parent => undef,
+                force_arguments => {},
+                force_path => undef,
                 region_wrapper => 1,
                 @_
                );
@@ -84,6 +99,8 @@ sub new {
     $self->qualified_name(Jifty->web->qualified_region($self));
     $self->default_path($args{path});
     $self->default_arguments($args{defaults});
+    $self->force_arguments($args{force_arguments});
+    $self->force_path($args{force_path});
     $self->arguments({});
     $self->parent($args{parent} || Jifty->web->current_region);
     $self->region_wrapper($args{region_wrapper});
@@ -158,7 +175,7 @@ sub argument {
     my $self = shift;
     my $name = shift;
     $self->{arguments}{$name} = shift if @_;
-    return $self->{arguments}{$name} || $self->default_argument($name);
+    return $self->force_arguments->{$name}||$self->{arguments}{$name} || $self->default_argument($name);
 }
 
 =head2 arguments [HASHREF]
@@ -171,7 +188,7 @@ also include all default arguments.
 sub arguments {
     my $self = shift;
     $self->{arguments} = shift if @_;
-    return { %{$self->{default_arguments}}, %{$self->{arguments}}};
+    return { %{$self->{default_arguments}}, %{$self->{arguments}}, %{$self->force_arguments}};
 }
 
 =head2 enter
@@ -179,7 +196,7 @@ sub arguments {
 Enters the region; this sets the qualified name based on
 L<Jifty::Web/qualified_region>, and uses that to pull runtime values
 for the L</path> and L</argument>s from the
-L<Jifty::Request/state_variables>.
+L<Jifty::Request/state_variables> before overriding them with the "force" versions.
 
 =cut
 
@@ -190,18 +207,26 @@ sub enter {
     push @{Jifty->web->{'region_stack'}}, $self;
 
     # Merge in the settings passed in via state variables
-    for (Jifty->web->request->state_variables) {
-        my $key = $_->key;
-        my $value = $_->value || '';
-        if ($key =~ /^region-(.*?)\.(.*)/ and $1 eq $self->qualified_name and $value  ne $self->default_argument($2)) {
+    for my $var (Jifty->web->request->state_variables) {
+        my $key = $var->key;
+        my $value = $var->value || '';
+
+        if ($key =~ /^region-(.*?)\.(.*)/ and $1 eq $self->qualified_name and $value ne $self->default_argument($2)) {
             $self->argument($2 => $value);
-            Jifty->web->set_variable("region-$1.$2" => $value);
         }
-        if ($key =~ /^region-(.*?)$/ and $1 eq $self->qualified_name and $value ne $self->default_path) {
+        if ($key =~ /^region-(.*)$/ and $1 eq $self->qualified_name and $value ne $self->default_path) {
             $self->path($value);
-            Jifty->web->set_variable("region-$1" => $value);
         }
+
+        # We should always inherit the state variables from the uplevel request.
+        Jifty->web->set_variable($key => $value);
     }
+
+    for my $argument (keys %{$self->force_arguments}) {
+            $self->argument($argument => $self->force_arguments->{$argument});
+    }
+
+    $self->path($self->force_path) if ($self->force_path);
 }
 
 =head2 exit 
@@ -297,11 +322,19 @@ sub render_as_subrequest {
     #XXX TODO: There's gotta be a better way to localize it
     my $region_content = '';
 
+    # template-declare based regions are printing to stdout
+    my $td_out = '';
+    Encode::_utf8_on($td_out);
+    open my $output_fh, '>>:utf8', \$td_out;
+    local *STDOUT = $output_fh;
+
+    local $main::DEBUG=1;
     # Call into the dispatcher
     Jifty->handler->dispatcher->handle_request;
 
     Jifty->handler->mason->interp->out_method($orig_out);
 
+    $$out_method .= $td_out if length($td_out);
     return;
 }
 
